@@ -7,7 +7,7 @@ use warnings;
 use Mojo::Base 'Mojo::EventEmitter';
 use Mojo::Util 'encode';
 
-our $VERSION = '1.03'; # VERSION
+our $VERSION = '1.04'; # VERSION
 
 has history          => sub { [] };
 has level            => 'debug';
@@ -31,7 +31,6 @@ sub new {
 
 sub _log {
     shift->emit( 'message', @_ );
-    return;
 }
 
 {
@@ -122,7 +121,7 @@ MojoX::Log::Dispatch::Simple - Simple Log::Dispatch replacement of Mojo::Log
 
 =head1 VERSION
 
-version 1.03
+version 1.04
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/MojoX-Log-Dispatch-Simple.svg)](https://travis-ci.org/gryphonshafer/MojoX-Log-Dispatch-Simple)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/MojoX-Log-Dispatch-Simple/badge.png)](https://coveralls.io/r/gryphonshafer/MojoX-Log-Dispatch-Simple)
@@ -419,6 +418,16 @@ L<CPAN Testers|http://www.cpantesters.org/distro/M/MojoX-Log-Dispatch-Simple.htm
 
 =for Pod::Coverage alert crit critical debug emerg emergency err fatal format info is_alert is_crit is_critical is_debug is_emerg is_emergency is_err is_error is_fatal is_info is_notice is_warn is_warning notice warn warning
 
+=head1 GRATITUDE
+
+Special thanks to the following for contributing to this module:
+
+=over 4
+
+*Tomohiro Hosaka
+
+=back
+
 =head1 AUTHOR
 
 Gryphon Shafer <gryphon@cpan.org>
